@@ -1,7 +1,7 @@
-use num_traits::{real::Real, One, Zero};
+use num_traits::{real::Real, Zero};
 use std::{
     cmp::PartialOrd,
-    ops::{Add, Div, Mul, Neg, Sub},
+    ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Neg, Sub, SubAssign},
 };
 
 /// This trait specifies some type to be a vector type.
@@ -16,17 +16,21 @@ where
 {
     /// The scalar type of the vector space.
     type Scalar: Real + PartialOrd;
-
-    /// The linear interpolation of two vectors.
-    fn lerp(self, other: Self, amount: Self::Scalar) -> Self {
-        self * (Self::Scalar::one() - amount) + other * amount
-    }
 }
 
 impl VectorSpace for f32 {
     type Scalar = f32;
 }
-
 impl VectorSpace for f64 {
     type Scalar = f64;
 }
+
+/// This trait is automatically implemented for vector spaces, which also implement assignment operations.
+pub trait VectorSpaceAssign:
+    VectorSpace + AddAssign + SubAssign + MulAssign<Self::Scalar> + DivAssign<Self::Scalar>
+{
+}
+impl<T> VectorSpaceAssign for T where
+    T: VectorSpace + AddAssign + SubAssign + MulAssign<Self::Scalar> + DivAssign<Self::Scalar>
+{
+}
